import { useState, useEffect } from "react";
import { Menu, X, Globe } from "lucide-react";
import { Button } from "@/components/ui/button";
import { useLanguage } from "@/contexts/LanguageContext";

const navLinks = [
  { name: "Services", href: "#services", hebrewName: "שירותים" },
  { name: "Process", href: "#process", hebrewName: "תהליך" },
  { name: "Contact", href: "#contact", hebrewName: "צור קשר" },
];

export default function Navbar() {
  const [isScrolled, setIsScrolled] = useState(false);
  const [mobileMenuOpen, setMobileMenuOpen] = useState(false);
  const [lastScrollY, setLastScrollY] = useState(0);
  const [hidden, setHidden] = useState(false);
  
  const { language, toggleLanguage, isLoading } = useLanguage();
  const isHebrew = language === "he";

  useEffect(() => {
    const handleScroll = () => {
      const currentScrollY = window.scrollY;
      
      // Determine if scrolled down from top
      if (currentScrollY > 50) {
        setIsScrolled(true);
      } else {
        setIsScrolled(false);
      }
      
      // Auto-hide on scroll down, show on scroll up
      if (currentScrollY > lastScrollY && currentScrollY > 200) {
        setHidden(true);
      } else {
        setHidden(false);
      }
      
      setLastScrollY(currentScrollY);
    };

    window.addEventListener("scroll", handleScroll, { passive: true });
    return () => window.removeEventListener("scroll", handleScroll);
  }, [lastScrollY]);

  // Handle smooth scrolling
  const handleLinkClick = (href) => {
    const targetId = href.replace('#', '');
    const element = document.getElementById(targetId);
    const navbarHeight = 80; // Approximate height of navbar
    
    if (element) {
      const offsetTop = element.getBoundingClientRect().top + window.pageYOffset - navbarHeight;
      
      window.scrollTo({
        top: offsetTop,
        behavior: 'smooth'
      });
      
      // Close mobile menu if open
      if (mobileMenuOpen) setMobileMenuOpen(false);
    }
  };

  const handleScrollToContact = () => {
    const contactSection = document.getElementById('contact');
    if (contactSection) {
      contactSection.scrollIntoView({ behavior: 'smooth' });
    }
    if (mobileMenuOpen) setMobileMenuOpen(false);
  };

  return (
    <header
      className={`fixed top-0 left-0 right-0 z-50 transition-all duration-300 ${
        hidden ? '-translate-y-full' : 'translate-y-0'
      } ${
        isScrolled
          ? "glass-dark shadow-lg border-b border-purple-500/10 neon-border"
          : "bg-transparent"
      }`}
    >
      <nav
        className={`container mx-auto px-4 sm:px-6 py-4 flex items-center justify-between ${
          isHebrew ? "flex-row-reverse" : ""
        }`}
      >
        <a 
          href="#hero" 
          className="flex items-center space-x-2 group"
          onClick={(e) => {
            e.preventDefault();
            handleLinkClick('#hero');
          }}
        >
          <div className="relative h-9 w-9 lg:h-10 lg:w-10 rounded-full bg-gradient-to-br from-purple-500 to-purple-700 flex items-center justify-center tech-glow">
            <span className="text-white font-bold text-lg lg:text-xl">I</span>
          </div>
          <span className="font-bold text-lg lg:text-xl bg-clip-text text-transparent bg-gradient-to-r from-white to-gray-300">
            INNOVAI
          </span>
        </a>

        {/* Desktop Navigation */}
        <div className="hidden md:flex items-center space-x-8">
          {navLinks.map((link) => (
            <a
              key={link.href}
              href={link.href}
              className="nav-link text-gray-300 hover:text-white transition-colors"
              onClick={(e) => {
                e.preventDefault();
                handleLinkClick(link.href);
              }}
            >
              {isHebrew ? link.hebrewName : link.name}
            </a>
          ))}
        </div>

        {/* Language switcher and CTA for desktop */}
        <div className="hidden md:flex items-center">
          <Button
            onClick={toggleLanguage}
            variant="ghost"
            size="icon"
            className="language-toggle text-gray-300 hover:text-white touch-target relative"
            aria-label={`Switch to ${isHebrew ? "English" : "Hebrew"}`}
            disabled={isLoading}
          >
            <Globe className="h-5 w-5 text-purple-300" />
            <span className="ml-2 text-sm font-medium">
              {isHebrew ? "EN" : "HE"}
            </span>
            {isLoading && (
              <span className="absolute -top-1 -right-1 flex h-3 w-3">
                <span className="absolute inline-flex h-full w-full rounded-full bg-purple-400 opacity-75"></span>
                <span className="relative inline-flex rounded-full h-3 w-3 bg-purple-500"></span>
              </span>
            )}
          </Button>
          
          <Button
            variant="default"
            className="ml-4 bg-gradient-to-r from-purple-600 to-purple-800 hover:from-purple-500 hover:to-purple-700 text-white text-base px-5 py-2 tech-border"
            onClick={handleScrollToContact}
          >
            {isHebrew ? "התחל עכשיו" : "Get Started"}
          </Button>
        </div>

        {/* Mobile Menu Button and Language */}
        <div className="md:hidden flex items-center space-x-2">
          <Button
            onClick={toggleLanguage}
            variant="ghost"
            size="icon"
            className="language-toggle text-gray-300 hover:text-white touch-target relative"
            aria-label={`Switch to ${isHebrew ? "English" : "Hebrew"}`}
            disabled={isLoading}
          >
            <Globe className="h-5 w-5 text-purple-300" />
            {isLoading && (
              <span className="absolute -top-1 -right-1 flex h-3 w-3">
                <span className="absolute inline-flex h-full w-full rounded-full bg-purple-400 opacity-75"></span>
                <span className="relative inline-flex rounded-full h-3 w-3 bg-purple-500"></span>
              </span>
            )}
          </Button>
          
          <Button
            variant="default"
            className="mr-2 bg-gradient-to-r from-purple-600 to-purple-800 hover:from-purple-500 hover:to-purple-700 text-white text-sm px-3 py-2"
            onClick={handleScrollToContact}
          >
            {isHebrew ? "התחל" : "Start"}
          </Button>
          
          <button
            onClick={() => setMobileMenuOpen(!mobileMenuOpen)}
            className="text-gray-300 hover:text-white touch-target"
            aria-label={mobileMenuOpen ? "Close menu" : "Open menu"}
            aria-expanded={mobileMenuOpen}
          >
            {mobileMenuOpen ? <X size={24} /> : <Menu size={24} />}
          </button>
        </div>
      </nav>

      {/* Mobile Menu */}
      {mobileMenuOpen && (
        <div className="md:hidden glass-dark overflow-hidden border-b border-purple-500/20 tech-border">
          <div className="container mx-auto px-4 sm:px-6 py-4">
            <ul className={`space-y-4 ${isHebrew ? "text-right" : ""}`}>
              {navLinks.map((link) => (
                <li key={link.href}>
                  <a
                    href={link.href}
                    className="nav-link text-gray-300 hover:text-white transition-colors block py-3 touch-target"
                    onClick={(e) => {
                      e.preventDefault();
                      handleLinkClick(link.href);
                    }}
                  >
                    {isHebrew ? link.hebrewName : link.name}
                  </a>
                </li>
              ))}
              <li>
                <Button
                  variant="default"
                  className="w-full bg-gradient-to-r from-purple-600 to-purple-800 hover:from-purple-500 hover:to-purple-700 text-white mt-4 py-3 touch-target tech-border"
                  onClick={handleScrollToContact}
                >
                  {isHebrew ? "התחל עכשיו" : "Get Started"}
                </Button>
              </li>
            </ul>
          </div>
        </div>
      )}
    </header>
  );
}